@@ -1,11 +1,7 @@
-import requests
-from bs4 import BeautifulSoup
-from fake_useragent import UserAgent
+from crsspd.req_tools import *
+from crsspd.selm_tools import SelenuimTools
 
-from req_tools import *
-from selm_tools import SelenuimTools
-
-class SpiderTools(object):
+class SpiderTools():
     def __init__(self,chrome_path='/Users/bappy/opt/chromedriver',headless=True):
         self.selm=SelenuimTools(chrome_path=chrome_path,headless=headless)
 
